@@ -1,67 +1,28 @@
 /*******************************************************************************
 
-  Recipient has requested a license and Intel Corporation ("Intel") is
-  willing to grant a license for the software entitled Linux Base Driver
-  for the Intel(R) PRO/1000 Familty of Adapters (e1000) (the "Software")
-  being provided by Intel Corporation.
   
-  The following definitions apply to this License:
+  Copyright(c) 1999 - 2002 Intel Corporation. All rights reserved.
   
-  "Licensed Patents" means patent claims licensable by Intel Corporation
-  which are necessarily infringed by the use or sale of the Software alone
-  or when combined with the operating system referred to below.
-  "Recipient" means the party to whom Intel delivers this Software.
-  "Licensee" means Recipient and those third parties that receive a license
-  to any operating system available under the GNU Public License version
-  2.0 or later.
+  This program is free software; you can redistribute it and/or modify it 
+  under the terms of the GNU General Public License as published by the Free 
+  Software Foundation; either version 2 of the License, or (at your option) 
+  any later version.
   
-  Copyright (c) 1999-2001 Intel Corporation All rights reserved.
+  This program is distributed in the hope that it will be useful, but WITHOUT 
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
+  more details.
   
-  The license is provided to Recipient and Recipient's Licensees under
-  the following terms.
+  You should have received a copy of the GNU General Public License along with
+  this program; if not, write to the Free Software Foundation, Inc., 59 
+  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
   
-  Redistribution and use in source and binary forms of the Software,
-  with or without modification, are permitted provided that the following
-  conditions are met:
+  The full GNU General Public License is included in this distribution in the
+  file called LICENSE.
   
-  Redistributions of source code of the Software may retain the above
-  copyright notice, this list of conditions and the following disclaimer.
-  Redistributions in binary form of the Software may reproduce the above
-  copyright notice, this list of conditions and the following disclaimer in
-  the documentation and/or other materials provided with the distribution.
-  Neither the name of Intel Corporation nor the names of its contributors
-  shall be used to endorse or promote products derived from this Software
-  without specific prior written permission.
-  
-  Intel hereby grants Recipient and Licensees a non-exclusive, worldwide,
-  royalty-free patent license under Licensed Patents to make, use, sell,
-  offer to sell, import and otherwise transfer the Software, if any, in
-  source code and object code form. This license shall include changes
-  to the Software that are error corrections or other minor changes
-  to the Software that do not add functionality or features when the
-  Software is incorporated in any version of a operating system that has
-  been distributed under the GNU General Public License 2.0 or later.
-  This patent license shall apply to the combination of the Software and
-  any operating system licensed under the GNU Public License version 2.0
-  or later if, at the time Intel provides the Software to Recipient, such
-  addition of the Software to the then publicly available versions of such
-  operating system available under the GNU Public License version 2.0 or
-  later (whether in gold, beta or alpha form) causes such combination to
-  be covered by the Licensed Patents. The patent license shall not apply
-  to any other combinations which include the Software. No hardware per
-  se is licensed hereunder.
-  
-  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
-  IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
-  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR ITS CONTRIBUTORS
-  BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
-  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
-  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
-  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
-  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
-  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
-  THE POSSIBILITY OF SUCH DAMAGE.
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
 
 *******************************************************************************/
 
@@ -176,7 +137,7 @@ bd_ans_hw_GetVlanId(BOARD_PRIVATE_STRUCT *bps,
     
     // The packet has a tag, so extract it.
     // the first rev had the special field byte swapped
-    if (adapter->shared.mac_type < e1000_82543)
+    if (adapter->hw.mac_type < e1000_82543)
     {
                 DEBUGLOG("bd_ans_hw_GetVlanId: getting vlanid on WiseMan\n");
         VlanId = (BYTE_SWAP_WORD(rxd->special) & 
@@ -242,7 +203,7 @@ bd_ans_hw_EnableVLAN(BOARD_PRIVATE_STRUCT *bps)
    // Read the RX control register.  We'll make changes and write
    // it back out at the end of the routine.
    //***************************************************************
-   TempRctlReg = E1000_READ_REG(&adapter->shared, RCTL);
+   TempRctlReg = E1000_READ_REG(&adapter->hw, RCTL);
 
 
    if (iANSdata->tag_mode == IANS_BD_TAGGING_802_3AC)
@@ -253,15 +214,15 @@ bd_ans_hw_EnableVLAN(BOARD_PRIVATE_STRUCT *bps)
       ** Set the VLAN Ethertype (VET) register, so the hardware knows
       ** what Ethertype to look for to strip the Q-tag.
       ******************************************************************/
-      E1000_WRITE_REG(&adapter->shared, VET, QTAG_TYPE);
+      E1000_WRITE_REG(&adapter->hw, VET, QTAG_TYPE);
    
       /**************************************************************
       ** Set VLAN Mode Enable bit in the Control register (CTRL.VME).
       ** This allows adding/stripping 802.3ac tags.
       **************************************************************/
-      DeviceControlReg = E1000_READ_REG(&adapter->shared, CTRL);
+      DeviceControlReg = E1000_READ_REG(&adapter->hw, CTRL);
       DeviceControlReg |= E1000_CTRL_VME;
-      E1000_WRITE_REG(&adapter->shared, CTRL, DeviceControlReg);
+      E1000_WRITE_REG(&adapter->hw, CTRL, DeviceControlReg);
 
 
       //**********************************************************
@@ -280,9 +241,9 @@ bd_ans_hw_EnableVLAN(BOARD_PRIVATE_STRUCT *bps)
                 BitInReg = iANSdata->VlanID[i] & 0x1F;  
 
                 // This is Read-Modify-Write operation
-                VftaReg = E1000_READ_REG_ARRAY(&adapter->shared, VFTA, VftaIndex);
+                VftaReg = E1000_READ_REG_ARRAY(&adapter->hw, VFTA, VftaIndex);
                 VftaReg |= (1 << BitInReg);
-                e1000_write_vfta(&adapter->shared, VftaIndex, VftaReg);
+                e1000_write_vfta(&adapter->hw, VftaIndex, VftaReg);
         }
           }
 
@@ -306,7 +267,7 @@ bd_ans_hw_EnableVLAN(BOARD_PRIVATE_STRUCT *bps)
    // Restore the saved Rctl register, along with our changed bits.
    //***************************************************************
 
-   E1000_WRITE_REG(&adapter->shared, RCTL, TempRctlReg);
+   E1000_WRITE_REG(&adapter->hw, RCTL, TempRctlReg);
  
    return BD_ANS_SUCCESS;
 }   
@@ -346,22 +307,22 @@ bd_ans_hw_DisableTagging(BOARD_PRIVATE_STRUCT *bps)
    // Read the RX control register.  We'll make changes and write
    // it back out at the end of the routine.
    //***************************************************************
-   TempRctlReg = E1000_READ_REG(&adapter->shared, RCTL);
+   TempRctlReg = E1000_READ_REG(&adapter->hw, RCTL);
 
 
    //***************************************************************
    // Reset VLAN Mode Enable bit in the Control register (CTRL.VME).
    // This turns off adding/stripping 802.3ac tags.
    //***************************************************************
-   DeviceControlReg = E1000_READ_REG(&adapter->shared, CTRL);
+   DeviceControlReg = E1000_READ_REG(&adapter->hw, CTRL);
    DeviceControlReg &= ~E1000_CTRL_VME;
-   E1000_WRITE_REG(&adapter->shared, CTRL, DeviceControlReg);
+   E1000_WRITE_REG(&adapter->hw, CTRL, DeviceControlReg);
 
    //**********************************************************
    // Clear the VLAN Filter Table Array (VFTA).
    //**********************************************************
 
-	e1000_clear_vfta(&adapter->shared);
+	e1000_clear_vfta(&adapter->hw);
 
    //************************************************************
    // Clear the VFE and ISLE bits in the Receive Control register.
@@ -370,7 +331,7 @@ bd_ans_hw_DisableTagging(BOARD_PRIVATE_STRUCT *bps)
    TempRctlReg &= ~E1000_RCTL_VFE;
 
 
-   E1000_WRITE_REG(&adapter->shared, RCTL, TempRctlReg);
+   E1000_WRITE_REG(&adapter->hw, RCTL, TempRctlReg);
   
    return BD_ANS_SUCCESS;
 }   
@@ -407,22 +368,22 @@ bd_ans_hw_EnablePriorityRx(BOARD_PRIVATE_STRUCT *bps)
    struct e1000_adapter *adapter = GIGABIT_ADAPTER_STRUCT(bps);
 
    DEBUGLOG("bd_ans_hw_EnablePriorityRx: enter\n");
-   TempRctlReg = E1000_READ_REG(&adapter->shared, RCTL);
+   TempRctlReg = E1000_READ_REG(&adapter->hw, RCTL);
 
 
    /******************************************************************
    ** Set the VLAN Ethertype (VET) register, so the hardware knows
    ** what Ethertype to look for to strip the Q-tag.
    ******************************************************************/
-   E1000_WRITE_REG(&adapter->shared, VET, ETHERNET_IEEE_VLAN_TYPE);
+   E1000_WRITE_REG(&adapter->hw, VET, ETHERNET_IEEE_VLAN_TYPE);
 
    /**************************************************************
    ** Set VLAN Mode Enable bit in the Control register (CTRL.VME).
    ** This allows adding/stripping 802.3ac tags.
    **************************************************************/
-   DeviceControlReg = E1000_READ_REG(&adapter->shared, CTRL);
+   DeviceControlReg = E1000_READ_REG(&adapter->hw, CTRL);
    DeviceControlReg |= E1000_CTRL_VME;
-   E1000_WRITE_REG(&adapter->shared, CTRL, DeviceControlReg);
+   E1000_WRITE_REG(&adapter->hw, CTRL, DeviceControlReg);
 
 
    //**********************************************************
@@ -432,9 +393,9 @@ bd_ans_hw_EnablePriorityRx(BOARD_PRIVATE_STRUCT *bps)
    // packets with priority-only information.
    //**********************************************************
 
-   VftaReg = E1000_READ_REG_ARRAY(&adapter->shared, VFTA, 0);
+   VftaReg = E1000_READ_REG_ARRAY(&adapter->hw, VFTA, 0);
    VftaReg |= 1;
-   e1000_write_vfta(&adapter->shared, 0, VftaReg);
+   e1000_write_vfta(&adapter->hw, 0, VftaReg);
 
    //************************************************************
    // Set the VFE bit in the Receive Control register, and clear
@@ -450,7 +411,7 @@ bd_ans_hw_EnablePriorityRx(BOARD_PRIVATE_STRUCT *bps)
    // Restore the saved Rctl register, along with our changed bits.
    //***************************************************************
 
-   E1000_WRITE_REG(&adapter->shared, RCTL, TempRctlReg);
+   E1000_WRITE_REG(&adapter->hw, RCTL, TempRctlReg);
    return BD_ANS_SUCCESS;
 }   
 #endif 
