@@ -1,67 +1,28 @@
 /*******************************************************************************
 
-  Recipient has requested a license and Intel Corporation ("Intel") is
-  willing to grant a license for the software entitled Linux Base Driver
-  for the Intel(R) PRO/1000 Familty of Adapters (e1000) (the "Software")
-  being provided by Intel Corporation.
   
-  The following definitions apply to this License:
+  Copyright(c) 1999 - 2002 Intel Corporation. All rights reserved.
   
-  "Licensed Patents" means patent claims licensable by Intel Corporation
-  which are necessarily infringed by the use or sale of the Software alone
-  or when combined with the operating system referred to below.
-  "Recipient" means the party to whom Intel delivers this Software.
-  "Licensee" means Recipient and those third parties that receive a license
-  to any operating system available under the GNU Public License version
-  2.0 or later.
+  This program is free software; you can redistribute it and/or modify it 
+  under the terms of the GNU General Public License as published by the Free 
+  Software Foundation; either version 2 of the License, or (at your option) 
+  any later version.
   
-  Copyright (c) 1999-2001 Intel Corporation All rights reserved.
+  This program is distributed in the hope that it will be useful, but WITHOUT 
+  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
+  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
+  more details.
   
-  The license is provided to Recipient and Recipient's Licensees under
-  the following terms.
+  You should have received a copy of the GNU General Public License along with
+  this program; if not, write to the Free Software Foundation, Inc., 59 
+  Temple Place - Suite 330, Boston, MA  02111-1307, USA.
   
-  Redistribution and use in source and binary forms of the Software,
-  with or without modification, are permitted provided that the following
-  conditions are met:
+  The full GNU General Public License is included in this distribution in the
+  file called LICENSE.
   
-  Redistributions of source code of the Software may retain the above
-  copyright notice, this list of conditions and the following disclaimer.
-  Redistributions in binary form of the Software may reproduce the above
-  copyright notice, this list of conditions and the following disclaimer in
-  the documentation and/or other materials provided with the distribution.
-  Neither the name of Intel Corporation nor the names of its contributors
-  shall be used to endorse or promote products derived from this Software
-  without specific prior written permission.
-  
-  Intel hereby grants Recipient and Licensees a non-exclusive, worldwide,
-  royalty-free patent license under Licensed Patents to make, use, sell,
-  offer to sell, import and otherwise transfer the Software, if any, in
-  source code and object code form. This license shall include changes
-  to the Software that are error corrections or other minor changes
-  to the Software that do not add functionality or features when the
-  Software is incorporated in any version of a operating system that has
-  been distributed under the GNU General Public License 2.0 or later.
-  This patent license shall apply to the combination of the Software and
-  any operating system licensed under the GNU Public License version 2.0
-  or later if, at the time Intel provides the Software to Recipient, such
-  addition of the Software to the then publicly available versions of such
-  operating system available under the GNU Public License version 2.0 or
-  later (whether in gold, beta or alpha form) causes such combination to
-  be covered by the Licensed Patents. The patent license shall not apply
-  to any other combinations which include the Software. No hardware per
-  se is licensed hereunder.
-  
-  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
-  IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
-  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
-  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR ITS CONTRIBUTORS
-  BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
-  OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
-  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
-  INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
-  CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
-  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
-  THE POSSIBILITY OF SUCH DAMAGE.
+  Contact Information:
+  Linux NICS <linux.nics@intel.com>
+  Intel Corporation, 5200 N.E. Elam Young Parkway, Hillsboro, OR 97124-6497
 
 *******************************************************************************/
 
@@ -318,7 +279,7 @@ typedef enum _IANS_BD_REQUEST_SUPPORT {
 
 typedef struct _IANS_BD_PARAM_HEADER
 {
-    // Cast from IANS_BASE_OPCODE to insure forward size compatibility 
+    /* Cast from IANS_BASE_OPCODE to insure forward size compatibility */
     /* u32 */ int    Opcode; 
 } IANS_BD_PARAM_HEADER, *PIANS_BD_PARAM_HEADER;
 
@@ -356,12 +317,44 @@ typedef struct _IANS_BD_PARAM_STATUS
 
 typedef struct _IANS_BD_IOC_PARAM_STATUS
 {
-    IANS_BD_PARAM_HEADER           Header;                /* Common to all commands */
+    IANS_BD_PARAM_HEADER           Header;          /* Common to all commands */
     IANS_BD_PARAM_STATUS   Status;
 } IANS_BD_IOC_PARAM_STATUS, *PIANS_BD_IOC_PARAM_STATUS;
 
 
 
+/*--------------------------------------------------------------------*
+ |                      Indication 
+ |                     ============                   
+ | This enum value is sent by the notify call back function
+ | called by the base driver for indication purposes.
+ *--------------------------------------------------------------------*/
+
+typedef enum _IANS_INDICATION 
+{
+    /* ----------  Basic Extention Indications  ---------- */
+    IANS_IND_EXT_HWMODIFY,                          
+                                   
+    IANS_IND_EXT_STATUS_CHANGE,     /* Report a new status */
+                                      
+    IANS_IND_XMIT_QUEUE_FULL, // tell ANS to stop transmit through this member
+
+    IANS_IND_XMIT_QUEUE_READY, // tell ANS to start transmit through this member
+                                      
+    IANS_IND_COMMA  /* Dummy to satisfy last ifdef'ed commma */
+        
+} IANS_INDICATION, *PIANS_INDICATION;
+
+
+
+
+typedef struct _IANS_BD_ANS_SET_CB {
+    IANS_BD_PARAM_HEADER           Header;
+    void *notify;
+} IANS_BD_ANS_SET_CB, *PIANS_BD_ANS_SET_CB;
+
+
+
 /*--------------------------------------------------------------------*
  |                    Identify yourself struct
  |                    ========================
@@ -373,7 +366,7 @@ typedef struct _IANS_BD_IOC_PARAM_STATUS
 
 typedef struct _IANS_BD_PARAM_IDENTIFY
 {
-    IANS_BD_PARAM_HEADER           Header;                 /* Common to all commands */
+    IANS_BD_PARAM_HEADER           Header;          /* Common to all commands */
 
     u8      iANSSignature[IANS_SIGNATURE_LENGTH]; 
     /* iANS fills copyright string*/
@@ -521,7 +514,7 @@ typedef struct _IANS_BD_PARAM_IVLAN_CAP
 
 typedef struct _IANS_BD_PARAM_IVLAN_SET_MODE
 {
-    IANS_BD_PARAM_HEADER           Header;                    /* Common to all commands */
+    IANS_BD_PARAM_HEADER           Header;          /* Common to all commands */
     u32           VlanIDRequest;           /* Cast from IANS_BD_REQUEST */
     u32           VlanIDFilteringRequest;  /* Cast from IANS_BD_REQUEST */
 } IANS_BD_PARAM_IVLAN_SET_MODE, *PIANS_BD_PARAM_IVLAN_SET_MODE;
@@ -673,38 +666,6 @@ typedef struct _Last_Attribute
 } Last_Attribute, *pLast_Attribute ;
 
 
-/*--------------------------------------------------------------------*
- |                      Indication 
- |                     ============                   
- | This enum value is sent by the notify call back function
- | called by the base driver for indication purposes.
- *--------------------------------------------------------------------*/
-
-typedef enum _IANS_INDICATION 
-{
-    /* ----------  Basic Extention Indications  ---------- */
-    IANS_IND_EXT_HWMODIFY,                          
-                                   
-    IANS_IND_EXT_STATUS_CHANGE,     /* Report a new status */
-                                      
-    IANS_IND_XMIT_QUEUE_FULL, // tell ANS to stop transmit through this member
-
-    IANS_IND_XMIT_QUEUE_READY, // tell ANS to start transmit through this member
-                                      
-    IANS_IND_COMMA  /* Dummy to satisfy last ifdef'ed commma */
-        
-} IANS_INDICATION, *PIANS_INDICATION;
-
-
-
-
-typedef struct _IANS_BD_ANS_SET_CB {
-    IANS_BD_PARAM_HEADER           Header;
-    void *notify;
-} IANS_BD_ANS_SET_CB, *PIANS_BD_ANS_SET_CB;
-
-
-
 /* ================================================================= *
  *                                                                   *
  *                              Rx Routing                           *
